<?php

namespace AppBundle\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpKernel\Event\FilterControllerEvent;
use AppBundle\Annotation\DemoControllerAnnotation;

class ControllerAnnotationSubscriber implements EventSubscriberInterface
{
    /**
     * @return array
     */
    public static function getSubscribedEvents()
    {
        return [
            KernelEvents::CONTROLLER_ARGUMENTS => ['annotationProcessor']
        ];
    }

    /**
     * Event called for processing our controller annotations
     *
     * @param FilterControllerEvent $event
     */
    public function annotationProcessor(FilterControllerEvent $event)
    {
        $annotation = $event->getRequest()->attributes->get('_demoAnnotation', null);
        if ($annotation instanceof DemoControllerAnnotation) {
            // we have our custom annotation on the called controller action

            if( strtolower($annotation->getAddDemoValue()) == 'true' ) {
                // and "addDemoValue" has been set to "true"

                // add an additional value to the request, just to demonstrate this was actually called and processed
                $event->getRequest()->attributes->set('demoValue', '42');
            }
        }
    }
}
